@@ -97,10 +97,10 @@ VideoStore::VideoStore(
   converted_in_samples(nullptr),
   filename(filename_in),
   format(format_in),
-  video_first_pts(0), /* starting pts of first in frame/packet */
-  video_first_dts(0),
-  audio_first_pts(0),
-  audio_first_dts(0),
+  video_first_pts(AV_NOPTS_VALUE),
+  video_first_dts(AV_NOPTS_VALUE),
+  audio_first_pts(AV_NOPTS_VALUE),
+  audio_first_dts(AV_NOPTS_VALUE),
   video_last_pts(AV_NOPTS_VALUE),
   audio_last_pts(AV_NOPTS_VALUE),
   next_dts(nullptr),
@@ -139,8 +139,10 @@ bool VideoStore::open() {
   if ( ret < 0 ) Warning("%s:%d: title set failed", __FILE__, __LINE__);
 
   oc->metadata = pmetadata;
-  out_format = oc->oformat;
-  //oc->oformat->flags |= AVFMT_TS_NONSTRICT; // allow non increasing dts
+#if !LIBAVFORMAT_VERSION_CHECK(59, 16, 0, 2, 0)
+  oc->oformat->flags |= AVFMT_TS_NONSTRICT; // allow non increasing dts
+#endif
+  out_format = const_cast<AVOutputFormat *>(oc->oformat);
 
   if (video_in_stream) {
 #if LIBAVCODEC_VERSION_CHECK(57, 64, 0, 64, 0)
@@ -1106,7 +1108,7 @@ int VideoStore::writeVideoFramePacket(const std::shared_ptr<ZMPacket> &zm_packet
 #endif
 
     int64_t in_pts = zm_packet->timestamp.tv_sec * (uint64_t)1000000 + zm_packet->timestamp.tv_usec;
-    if (!video_first_pts) {
+    if (video_first_pts == AV_NOPTS_VALUE) {
       video_first_pts = in_pts;
       Debug(2, "No video_first_pts, set to (%" PRId64 ") secs(%" PRIi64 ") usecs(%" PRIi64 ")",
             video_first_pts,
@@ -1201,19 +1203,19 @@ int VideoStore::writeVideoFramePacket(const std::shared_ptr<ZMPacket> &zm_packet
     opkt.duration = ipkt->duration;
 
     if (ipkt->dts != AV_NOPTS_VALUE) {
-      if (!video_first_dts) {
+      if (video_first_dts == AV_NOPTS_VALUE) {
         Debug(2, "Starting video first_dts will become %" PRId64, ipkt->dts);
         video_first_dts = ipkt->dts;
       }
       opkt.dts = ipkt->dts - video_first_dts;
-    } else {
-      opkt.dts = next_dts[video_out_stream->index] ? av_rescale_q(next_dts[video_out_stream->index], video_out_stream->time_base, video_in_stream->time_base) : 0;
-      Debug(3, "Setting dts to video_next_dts %" PRId64 " from %" PRId64, opkt.dts, next_dts[video_out_stream->index]);
+    //} else {
+      //opkt.dts = next_dts[video_out_stream->index] ? av_rescale_q(next_dts[video_out_stream->index], video_out_stream->time_base, video_in_stream->time_base) : 0;
+      //Debug(3, "Setting dts to video_next_dts %" PRId64 " from %" PRId64, opkt.dts, next_dts[video_out_stream->index]);
     }
-    if (ipkt->pts != AV_NOPTS_VALUE) {
+    if ((ipkt->pts != AV_NOPTS_VALUE) and (video_first_dts != AV_NOPTS_VALUE)) {
       opkt.pts = ipkt->pts - video_first_dts;
-    } else {
-      opkt.pts = AV_NOPTS_VALUE;
+    //} else {
+      //opkt.pts = opkt.dts;
     }
 
     av_packet_rescale_ts(&opkt, video_in_stream->time_base, video_out_stream->time_base);
@@ -1238,7 +1240,7 @@ int VideoStore::writeAudioFramePacket(const std::shared_ptr<ZMPacket> &zm_packet
   int ret;
   ZM_DUMP_STREAM_PACKET(audio_in_stream, (*ipkt), "input packet");
 
-  if (!audio_first_dts) {
+  if (audio_first_dts == AV_NOPTS_VALUE) {
     audio_first_dts = ipkt->dts;
     audio_next_pts = audio_out_ctx->frame_size;
     Debug(3, "audio first_dts to %" PRId64, audio_first_dts);
@@ -1297,8 +1299,13 @@ int VideoStore::writeAudioFramePacket(const std::shared_ptr<ZMPacket> &zm_packet
     opkt.flags = ipkt->flags;
 
     opkt.duration = ipkt->duration;
-    opkt.pts = ipkt->pts - audio_first_dts;
-    opkt.dts = ipkt->dts - audio_first_dts;
+    if (audio_first_dts != AV_NOPTS_VALUE) {
+      opkt.pts = ipkt->pts - audio_first_dts;
+      opkt.dts = ipkt->dts - audio_first_dts;
+    } else {
+      opkt.pts = ipkt->pts;
+      opkt.dts = ipkt->dts;
+    }
 
     ZM_DUMP_STREAM_PACKET(audio_in_stream, (*ipkt), "after pts adjustment");
     av_packet_rescale_ts(&opkt, audio_in_stream->time_base, audio_out_stream->time_base);
@@ -1320,10 +1327,14 @@ int VideoStore::write_packet(AVPacket *pkt, AVStream *stream) {
       last_dts[stream->index] = 0;
     } 
     pkt->dts = last_dts[stream->index];
-  } else if (pkt->dts < last_dts[stream->index]) {
-    Warning("non increasing dts, fixing. our dts %" PRId64 " stream %d last_dts %" PRId64,
-        pkt->dts, stream->index, last_dts[stream->index]);
-    pkt->dts = last_dts[stream->index];
+  } else {
+    if ((last_dts[stream->index] != AV_NOPTS_VALUE) and (pkt->dts < last_dts[stream->index])) {
+      Warning("non increasing dts, fixing. our dts %" PRId64 " stream %d last_dts %" PRId64,
+          pkt->dts, stream->index, last_dts[stream->index]);
+      pkt->dts = last_dts[stream->index];
+    }
+    next_dts[stream->index] = pkt->dts + pkt->duration;
+    last_dts[stream->index] = pkt->dts;
   }
 
   if (pkt->pts == AV_NOPTS_VALUE) {
@@ -1340,8 +1351,6 @@ int VideoStore::write_packet(AVPacket *pkt, AVStream *stream) {
   }
 
   ZM_DUMP_STREAM_PACKET(stream, (*pkt), "finished pkt");
-  next_dts[stream->index] = pkt->dts + pkt->duration;
-  last_dts[stream->index] = pkt->dts;
   Debug(3, "next_dts for stream %d has become %" PRId64 " last_dts %" PRId64,
       stream->index, next_dts[stream->index], last_dts[stream->index]);
 
