@@ -90,12 +90,12 @@ echo json_encode($user_without_password);
 ?>;
 var running = <?php echo daemonCheck()?'true':'false' ?>;
 
-var STATE_UNKNOWN = <?php echo STATE_UNKNOWN ?>;
-var STATE_IDLE = <?php echo STATE_IDLE ?>;
-var STATE_PREALARM = <?php echo STATE_PREALARM ?>;
-var STATE_ALARM = <?php echo STATE_ALARM ?>;
-var STATE_ALERT = <?php echo STATE_ALERT ?>;
-var STATE_TAPE = <?php echo STATE_TAPE ?>;
+const STATE_UNKNOWN = <?php echo STATE_UNKNOWN ?>;
+const STATE_IDLE = <?php echo STATE_IDLE ?>;
+const STATE_PREALARM = <?php echo STATE_PREALARM ?>;
+const STATE_ALARM = <?php echo STATE_ALARM ?>;
+const STATE_ALERT = <?php echo STATE_ALERT ?>;
+const STATE_TAPE = <?php echo STATE_TAPE ?>;
 
 const CMD_NONE = <?php echo CMD_NONE ?>;
 const CMD_PAUSE = <?php echo CMD_PAUSE ?>;
@@ -123,3 +123,10 @@ stateStrings[STATE_PREALARM] = "<?php echo translate('Prealarm') ?>";
 stateStrings[STATE_ALARM] = "<?php echo translate('Alarm') ?>";
 stateStrings[STATE_ALERT] = "<?php echo translate('Alert') ?>";
 stateStrings[STATE_TAPE] = "<?php echo translate('Record') ?>";
+
+<?php
+global $config;
+foreach ($config as $name=>$c) {
+    echo 'const '. $name . ' = \''.preg_replace('/(\n\r?)/', '\\\\$1', $c['Value']).'\';'.PHP_EOL;
+}
+?>
