@@ -10,26 +10,6 @@
   global $streamMode;
   global $popup;
 ?>
-//
-// Import constants
-//
-var CMD_NONE = <?php echo CMD_NONE ?>;
-var CMD_PAUSE = <?php echo CMD_PAUSE ?>;
-var CMD_PLAY = <?php echo CMD_PLAY ?>;
-var CMD_VARPLAY = <?php echo CMD_VARPLAY ?>;
-var CMD_STOP = <?php echo CMD_STOP ?>;
-var CMD_FASTFWD = <?php echo CMD_FASTFWD ?>;
-var CMD_SLOWFWD = <?php echo CMD_SLOWFWD ?>;
-var CMD_SLOWREV = <?php echo CMD_SLOWREV ?>;
-var CMD_FASTREV = <?php echo CMD_FASTREV ?>;
-var CMD_ZOOMIN = <?php echo CMD_ZOOMIN ?>;
-var CMD_ZOOMOUT = <?php echo CMD_ZOOMOUT ?>;
-var CMD_PAN = <?php echo CMD_PAN ?>;
-var CMD_SCALE = <?php echo CMD_SCALE ?>;
-var CMD_PREV = <?php echo CMD_PREV ?>;
-var CMD_NEXT = <?php echo CMD_NEXT ?>;
-var CMD_SEEK = <?php echo CMD_SEEK ?>;
-var CMD_QUERY = <?php echo CMD_QUERY ?>;
 
 var SCALE_BASE = <?php echo SCALE_BASE ?>;
 
