@@ -14,7 +14,7 @@ function selectLayout(element) {
       monitor = monitors[i];
       // Need to clear the current positioning, and apply the new
 
-      monitor_frame = $j('#monitorFrame'+monitor.id);
+      monitor_frame = $j('#monitor'+monitor.id);
       if (!monitor_frame) {
         console.log('Error finding frame for ' + monitor.id);
         continue;
@@ -43,37 +43,20 @@ function selectLayout(element) {
       // For freeform, we don't touch the width/height/scale settings, but we may need to update sizing and scales
       setCookie('zmMontageScale', '', 3600);
       $j('#scale').val('0');
-      $j('#width').val('0');
+      $j('#width').val('auto');
     }
   } // end if a stored layout
   if (!layout) {
     console.log('No layout?');
     return;
   }
-  var width = parseInt($j('#width').val());
-  var height = parseInt($j('#height').val());
+  var width = $j('#width').val();
+  var height = $j('#height').val();
   var scale = $j('#scale').val();
 
   for (var i = 0, length = monitors.length; i < length; i++) {
     var monitor = monitors[i];
-
-    var stream_scale = 0;
-    if (parseInt(scale) > 0) {
-      stream_scale = scale;
-    } else if (width) {
-      stream_scale = parseInt(100*parseInt(width)/monitor.width);
-    } else if (height) {
-      stream_scale = parseInt(100*parseInt(height)/monitor.height);
-    } else if (layouts[layout_id].Name != 'Freeform') {
-      monitor_frame = $j('#monitorFrame'+monitor.id);
-      console.log("Monitor frame width : " + monitor_frame.width() + " monitor Width: " + monitor.width);
-      if (monitor_frame.width() < monitor.width) {
-        stream_scale = parseInt(100 * monitor_frame.width() / monitor.width);
-        // Round to a multiple of 5, so 53 become 50% etc
-        stream_scale = Math.floor(stream_scale/5)*5;
-      }
-    }
-    monitor.setStreamScale(stream_scale);
+    monitor.setScale(scale, width, height);
   } // end foreach monitor
 } // end function selectLayout(element)
 
@@ -85,7 +68,7 @@ function changeHeight() {
     monitor_frame = $j('#monitor'+monitor.id + " .monitorStream");
     monitor_frame.css('height', height);
     monitor_img = $j('#liveStream'+monitor.id);
-    monitor_img.css('height', parseInt(height) ? height+'px' : 'auto');
+    monitor_img.css('height', height);
   }
 }
 
@@ -93,36 +76,18 @@ function changeHeight() {
  * called when the widthControl select elements are changed
  */
 function changeWidth() {
-  var width = parseInt($j('#width').val());
-  var height = parseInt($j('#height').val());
-  $j('#width').val(width);
-  $j('#height').val(height);
+  var width = $j('#width').val();
+  var height = $j('#height').val();
 
   // Reset frame css
   $j('#zmMontageLayout').val(freeform_layout_id);
   selectLayout();
+  $j('#width').val(width);
+  $j('#height').val(height);
 
   for ( var i = 0, length = monitors.length; i < length; i++ ) {
     var monitor = monitors[i];
-
-    // Scale the frame
-    monitor_frame = $j('#monitorFrame'+monitor.id);
-    if ( !monitor_frame ) {
-      console.log("Error finding frame for " + monitor.id);
-      continue;
-    }
-    monitor_frame.css('width', ( width ? width+'px' : 'auto'));
-    monitor_frame.css('height', ( height ? height+'px' : 'auto'));
-    var scale = 100;
-    if ( width ) {
-      scale = parseInt(100*width/monitor.width);
-    } else if ( height ) {
-      scale = parseInt(100*height/monitor.height);
-    }
-    monitor_img = $j('#liveStream'+monitor.id);
-    monitor_img.css('width', parseInt(width) ? width+'px' : 'auto');
-
-    monitor.setStreamScale(scale);
+    monitor.setScale('0', width, height);
   } // end foreach monitor
   $j('#scale').val('0');
   setCookie('zmMontageScale', '0', 3600);
@@ -137,18 +102,18 @@ function changeWidth() {
  */
 function changeScale() {
   var scale = $j('#scale').val();
-  $j('#width').val('0'); //auto
-  $j('#height').val('0'); //auto
+  $j('#width').val('auto');
+  $j('#height').val('auto');
   setCookie('zmMontageScale', scale, 3600);
-  setCookie('zmMontageWidth', '', 3600);
-  setCookie('zmMontageHeight', '', 3600);
+  setCookie('zmMontageWidth', 'auto', 3600);
+  setCookie('zmMontageHeight', 'auto', 3600);
   $j('#zmMontageLayout').val(freeform_layout_id);
   selectLayout('#zmMontageLayout');
   for ( let i = 0, length = monitors.length; i < length; i++ ) {
     const monitor = monitors[i];
 
     // Scale the frame
-    monitor_frame = $j('#monitorFrame'+monitor.id);
+    monitor_frame = $j('#monitor'+monitor.id);
     if ( !monitor_frame ) {
       console.log("Error finding frame for " + monitor.id);
       continue;
@@ -246,34 +211,48 @@ function takeSnapshot() {
   window.location = '?view=snapshot&action=create&'+monitor_ids.join('&');
 }
 
+function handleClick(evt) {
+  evt.preventDefault();
+
+  const el = evt.currentTarget;
+  const id = el.getAttribute("data-monitor-id");
+
+  const url = '?view=watch&mid='+id;
+  if (evt.ctrlKey) {
+    window.open(url, '_blank');
+  } else {
+    window.location.assign(url);
+  }
+}
+
 var monitors = new Array();
 function initPage() {
   $j("#hdrbutton").click(function() {
     $j("#flipMontageHeader").slideToggle("slow");
     $j("#hdrbutton").toggleClass('glyphicon-menu-down').toggleClass('glyphicon-menu-up');
-    setCookie( 'zmMontageHeaderFlip', $j('#hdrbutton').hasClass('glyphicon-menu-up') ? 'up' : 'down', 3600);
+    setCookie('zmMontageHeaderFlip', $j('#hdrbutton').hasClass('glyphicon-menu-up') ? 'up' : 'down', 3600);
   });
-  if ( getCookie('zmMontageHeaderFlip') == 'down' ) {
+  if (getCookie('zmMontageHeaderFlip') == 'down') {
     // The chosen dropdowns require the selects to be visible, so once chosen has initialized, we can hide the header
     $j("#flipMontageHeader").slideToggle("fast");
     $j("#hdrbutton").toggleClass('glyphicon-menu-down').toggleClass('glyphicon-menu-up');
   }
 
-  for ( var i = 0, length = monitorData.length; i < length; i++ ) {
+  for (let i = 0, length = monitorData.length; i < length; i++) {
     monitors[i] = new MonitorStream(monitorData[i]);
-
+  }
+  selectLayout('#zmMontageLayout');
+  for (let i = 0, length = monitorData.length; i < length; i++) {
     // Start the fps and status updates. give a random delay so that we don't assault the server
-    var delay = Math.round( (Math.random()+0.5)*statusRefreshTimeout );
-    console.log("delay: " + delay);
+    var delay = Math.round((Math.random()+0.5)*statusRefreshTimeout);
     monitors[i].start(delay);
 
     var interval = monitors[i].refresh;
-    if ( monitors[i].type == 'WebSite' && interval > 0 ) {
+    if (monitors[i].type == 'WebSite' && interval > 0) {
       setInterval(reloadWebSite, interval*1000, i);
     }
-    monitors[i].setup_onclick();
+    monitors[i].setup_onclick(handleClick);
   }
-  selectLayout('#zmMontageLayout');
 }
 // Kick everything off
 $j(document).ready(initPage);
