@@ -96,45 +96,17 @@ function showPtzControls() {
 }
 
 function changeScale() {
-  var scale = $j('#scale').val();
-  var newWidth;
-  var newHeight;
+  const scale = $j('#scale').val();
 
   // Always turn it off, we will re-add it below. I don't know if you can add a callback multiple
   // times and what the consequences would be
   $j(window).off('resize', endOfResize); //remove resize handler when Scale to Fit is not active
   if (scale == '0') {
-    var newSize = scaleToFit(monitorWidth, monitorHeight, $j('#liveStream'+monitorId), $j('#replayStatus'));
-    newWidth = newSize.width;
-    newHeight = newSize.height;
-    autoScale = newSize.autoScale;
     $j(window).on('resize', endOfResize); //remove resize handler when Scale to Fit is not active
-  } else if (parseInt(scale) > 0) {
-    newWidth = monitorWidth * scale / SCALE_BASE;
-    newHeight = monitorHeight * scale / SCALE_BASE;
   }
 
   setCookie('zmWatchScale'+monitorId, scale, 3600);
-
-  var streamImg = $j('#liveStream'+monitorId);
-  if (streamImg) {
-    const oldSrc = streamImg.attr('src');
-    const newSrc = oldSrc.replace(/scale=\d+/i, 'scale='+((scale == '0') ? autoScale : scale));
-
-    streamImg.width(newWidth);
-    streamImg.height(newHeight);
-    if (newSrc != oldSrc) {
-
-      clearTimeout(statusCmdTimer);
-      streamCommand(CMD_QUIT);
-      streamImg.attr('src', '');
-      streamImg.attr('src', newSrc);
-      if (statusCmdTimer) // Only start it if one was set to begin with
-        statusCmdTimer = setTimeout(statusCmdQuery, statusRefreshTimeout);
-    }
-  } else {
-    console.error('No element found for liveStream'+monitorId);
-  }
+  monitorStream.setScale(scale, $j('#width').val(), $j('#height').val());
 } // end function changeScale
 
 function setAlarmState(currentAlarmState) {
@@ -337,7 +309,7 @@ function getStreamCmdResponse(respObj, respText) {
   streamCmdTimer = setTimeout(streamCmdQuery, streamCmdTimeout);
 }
 
-function streamCmdPause(action) {
+function onPause() {
   setButtonState('pauseBtn', 'active');
   setButtonState('playBtn', 'inactive');
   setButtonState('stopBtn', 'inactive');
@@ -347,18 +319,19 @@ function streamCmdPause(action) {
     setButtonState('slowRevBtn', 'inactive');
     setButtonState('fastRevBtn', 'inactive');
   }
+}
+
+function streamCmdPause(action) {
+  onPause();
   if (action) {
-    var data = {};
-    if (auth_hash) data.auth = auth_hash;
-    data.command = CMD_PAUSE;
-    streamCmdReq(data);
+    monitorStream.streamCommand(CMD_PAUSE);
   }
 }
 
-function streamCmdPlay(action) {
+function onPlay() {
   setButtonState('pauseBtn', 'inactive');
   setButtonState('playBtn', 'active');
-  if (streamStatus.delayed == true) {
+  if (monitorStream.status.delayed == true) {
     setButtonState('stopBtn', 'inactive');
     if (monitorStreamReplayBuffer) {
       setButtonState('fastFwdBtn', 'inactive');
@@ -375,20 +348,13 @@ function streamCmdPlay(action) {
       setButtonState('fastRevBtn', 'unavail');
     }
   }
-  if (action) {
-    var data = {};
-    if (auth_hash) data.auth = auth_hash;
-    data.command = CMD_PLAY;
-    streamCmdReq(data);
-  }
 }
 
-function streamCmdReq(data) {
-  $j.getJSON(monitorUrl + '?view=request&request=stream&connkey='+connKey, data)
-      .done(getStreamCmdResponse)
-      .fail(getStreamCmdError);
-
-  streamCmdTimer = null;
+function streamCmdPlay(action) {
+  onPlay();
+  if (action) {
+    monitorStream.streamCommand(CMD_PLAY);
+  }
 }
 
 function streamCmdStop(action) {
@@ -402,10 +368,7 @@ function streamCmdStop(action) {
     setButtonState('fastRevBtn', 'unavail');
   }
   if (action) {
-    var data = {};
-    if (auth_hash) data.auth = auth_hash;
-    data.command = CMD_STOP;
-    streamCmdReq(data);
+    monitorStream.streamCommand(CMD_STOP);
   }
   setButtonState('stopBtn', 'unavail');
   setButtonState('playBtn', 'active');
@@ -422,10 +385,7 @@ function streamCmdFastFwd(action) {
     setButtonState('fastRevBtn', 'inactive');
   }
   if (action) {
-    var data = {};
-    if (auth_hash) data.auth = auth_hash;
-    data.command = CMD_FASTFWD;
-    streamCmdReq(data);
+    monitorStream.streamCommand(CMD_FASTFWD);
   }
 }
 
@@ -440,10 +400,7 @@ function streamCmdSlowFwd(action) {
     setButtonState('fastRevBtn', 'inactive');
   }
   if (action) {
-    var data = {};
-    if (auth_hash) data.auth = auth_hash;
-    data.command = CMD_SLOWFWD;
-    streamCmdReq(data);
+    monitorStream.streamCommand(CMD_SLOWFWD);
   }
   setButtonState('pauseBtn', 'active');
   if (monitorStreamReplayBuffer) {
@@ -462,10 +419,7 @@ function streamCmdSlowRev(action) {
     setButtonState('fastRevBtn', 'inactive');
   }
   if (action) {
-    var data = {};
-    if (auth_hash) data.auth = auth_hash;
-    data.command = CMD_SLOWREV;
-    streamCmdReq(data);
+    monitorStream.streamCommand(CMD_SLOWREV);
   }
   setButtonState('pauseBtn', 'active');
   if (monitorStreamReplayBuffer) {
@@ -484,44 +438,24 @@ function streamCmdFastRev(action) {
     setButtonState('fastRevBtn', 'inactive');
   }
   if (action) {
-    var data = {};
-    if (auth_hash) data.auth = auth_hash;
-    data.command = CMD_FASTREV;
-    streamCmdReq(data);
+    monitorStream.streamCommand(CMD_FASTREV);
   }
 }
 
 function streamCmdZoomIn(x, y) {
-  var data = {};
-  if (auth_hash) data.auth = auth_hash;
-  data.x = x;
-  data.y = y;
-  data.command = CMD_ZOOMIN;
-  streamCmdReq(data);
+  monitorStream.streamCommand({x: x, y:y, command: CMD_ZOOMIN});
 }
 
 function streamCmdZoomOut() {
-  var data = {};
-  if (auth_hash) data.auth = auth_hash;
-  data.command = CMD_ZOOMOUT;
-  streamCmdReq(data);
+  monitorStream.streamCommand(CMD_ZOOMOUT);
 }
 
 function streamCmdScale(scale) {
-  var data = {};
-  if (auth_hash) data.auth = auth_hash;
-  data.command = CMD_SCALE;
-  data.scale = scale;
-  streamCmdReq(data);
+  monitorStream.streamCommand({scale: scale, command: CMD_SCALE});
 }
 
 function streamCmdPan(x, y) {
-  var data = {};
-  if (auth_hash) data.auth = auth_hash;
-  data.x = x;
-  data.y = y;
-  data.command = CMD_PAN;
-  streamCmdReq(data);
+  monitorStream.streamCommand({x: x, y:y, command: CMD_pAN});
 }
 
 function streamCmdQuery() {
@@ -571,6 +505,7 @@ function alarmCmdReq(data) {
 
 function getAlarmCmdResponse(respObj, respText) {
   checkStreamForErrors('getAlarmCmdResponse', respObj);
+  if (respObj.message) alert(respObj.message);
 }
 
 function cmdDisableAlarms() {
@@ -864,6 +799,10 @@ function msieVer() {
   }
 }
 
+function refresh_events_table() {
+  table.bootstrapTable('refresh');
+}
+
 function initPage() {
   if (canView.Control) {
     // Load the PTZ Preset modal into the DOM
@@ -873,6 +812,34 @@ function initPage() {
   }
 
   if (monitorType != 'WebSite') {
+      monitorStream = new MonitorStream(monitorData[monIdx]);
+    monitorStream.setBottomElement(document.getElementById('dvrControls'));
+
+    // Start the fps and status updates. give a random delay so that we don't assault the server
+    monitorStream.setScale($j('#scale').val(), $j('#width').val(), $j('#height').val());
+    monitorStream.start();
+    if (streamMode == 'single') {
+      monitorStream.setup_onclick(fetchImage);
+    } else {
+      monitorStream.setup_onclick(handleClick);
+    }
+    monitorStream.setup_onpause(onPause);
+    monitorStream.setup_onplay(onPlay);
+    monitorStream.setup_onalarm(refresh_events_table);
+
+    monitorStream.setButton('enableAlarmButton', enableAlmBtn);
+    monitorStream.setButton('forceAlarmButton', forceAlmBtn);
+    monitorStream.setButton('zoomOutButton', $j('zoomOutBtn'));
+    if (canEdit.Monitors) {
+      // Will be enabled by streamStatus ajax
+      enableAlmBtn.on('click', cmdAlarm);
+      forceAlmBtn.on('click', cmdForce);
+    } else {
+      forceAlmBtn.prop('title', forceAlmBtn.prop('title') + ': disabled because cannot edit Monitors');
+      enableAlmBtn.prop('title', enableAlmBtn.prop('title') + ': disabled because cannot edit Monitors');
+    }
+
+/*
     if (streamMode == 'single') {
       statusCmdTimer = setTimeout(statusCmdQuery, (Math.random()+0.1)*statusRefreshTimeout);
       setInterval(watchdogCheck, statusRefreshTimeout*2, 'status');
@@ -899,6 +866,7 @@ function initPage() {
         }
       } // end if have streamImg
     } // streamMode native or single
+    */
 
     if (refreshApplet && appletRefreshTime) {
       setTimeout(appletRefresh, appletRefreshTime*1000);
@@ -909,7 +877,6 @@ function initPage() {
     document.querySelectorAll('select[name="scale"]').forEach(function(el) {
       el.onchange = window['changeScale'];
     });
-    changeScale();
   } else if (monitorRefresh > 0) {
     setInterval(reloadWebSite, monitorRefresh*1000);
   }
